@@ -65,6 +65,12 @@ class PushRequest(RpcRequest):
 	def set_Body(self,Body):
 		self.add_query_param('Body',Body)
 
+	def get_JobKey(self):
+		return self.get_query_params().get('JobKey')
+
+	def set_JobKey(self,JobKey):
+		self.add_query_param('JobKey',JobKey)
+
 	def get_PushTime(self):
 		return self.get_query_params().get('PushTime')
 
@@ -131,6 +137,24 @@ class PushRequest(RpcRequest):
 	def set_AndroidXiaoMiNotifyBody(self,AndroidXiaoMiNotifyBody):
 		self.add_query_param('AndroidXiaoMiNotifyBody',AndroidXiaoMiNotifyBody)
 
+	def get_AndroidPopupActivity(self):
+		return self.get_query_params().get('AndroidPopupActivity')
+
+	def set_AndroidPopupActivity(self,AndroidPopupActivity):
+		self.add_query_param('AndroidPopupActivity',AndroidPopupActivity)
+
+	def get_AndroidPopupTitle(self):
+		return self.get_query_params().get('AndroidPopupTitle')
+
+	def set_AndroidPopupTitle(self,AndroidPopupTitle):
+		self.add_query_param('AndroidPopupTitle',AndroidPopupTitle)
+
+	def get_AndroidPopupBody(self):
+		return self.get_query_params().get('AndroidPopupBody')
+
+	def set_AndroidPopupBody(self,AndroidPopupBody):
+		self.add_query_param('AndroidPopupBody',AndroidPopupBody)
+
 	def get_AndroidMusic(self):
 		return self.get_query_params().get('AndroidMusic')
 
@@ -213,4 +237,4 @@ class PushRequest(RpcRequest):
 		return self.get_query_params().get('iOSExtParameters')
 
 	def set_iOSExtParameters(self,iOSExtParameters):
-		self.add_query_param('iOSExtParameters',iOSExtParameters)
\ No newline at end of file
+		self.add_query_param('iOSExtParameters',iOSExtParameters)
